@@ -135,7 +135,7 @@ class BeoPlay(object):
                         if data and len(data)>0:
                             data = data.decode("utf-8").replace("\r", "").replace("\n", "")
                             if(len(data)>0):
-                                LOG.info("Update status: " + self._name + data)
+                                LOG.info("Update status: %s %s" % (self._name , data))
                                 data_json = json.loads(data)
                                 self._processNotification(data_json)
                                 if callback is not None:
@@ -150,8 +150,8 @@ class BeoPlay(object):
                     )
                     return False
 
-        except (asyncio.TimeoutError, aiohttp.ClientError):
-            LOG.info("Client connection error, marking %s as offline", self._name)
+        except (asyncio.TimeoutError, aiohttp.ClientError) as _e:
+            LOG.info("Client error %s on %s" % ( str(_e), self._name))
             raise
 
         return True
@@ -556,6 +556,7 @@ class BeoPlay(object):
             self.media_languages = None
             if 'image' in data["notification"]["data"] and data["notification"]["data"]["image"]:
                 self.media_url = data["notification"]["data"]["image"][0]["url"]
+                self.media_url = self.media_url.replace(".:8080/",":8080/") # some B&O devices provide a hostname with trailing '.' which doesn't resolve
             if 'name' in data["notification"]["data"]:
                 self.media_artist = data["notification"]["data"]["name"]
             if 'liveDescription' in data["notification"]["data"]:
